.. imreg_dft documentation master file, created by
   sphinx-quickstart2 on Sun Oct 12 15:24:34 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to imreg_dft's documentation!
=====================================

Contents:

.. toctree::
   :maxdepth: 2

   overview.rst
   quickstart.rst
   cli.rst
   cli-advanced.rst
   api.rst
   devel.rst
   changelog.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

